Exception: NtiReceiptBuilder::InvalidVariablesError

Inherits:
Error
  • Object
show all
Defined in:
lib/nti_receipt_builder/errors.rb

Overview

Raised when a Variables subclass is malformed — MAPPINGS missing or not a Hash, a mapped method that does not exist, an override for a key absent from MAPPINGS, or more than one key declaring columns:.